@@ -31,6 +31,7 @@ func TestClient_List(t *testing.T) {
 		registerExpectations func(*testing.T, *mock.MockDBRPsApi)
 		expectedError        error
 		outLines             []string
+		virtLines            []string
 	}{
 		{
 			name:          "no org id or org name",
@@ -74,6 +75,16 @@ func TestClient_List(t *testing.T) {
 							BucketID:        "456",
 							RetentionPolicy: "someRP",
 							Default:         true,
+							Virtual:         api.PtrBool(false),
+							OrgID:           "1234123412341234",
+						},
+						{
+							Id:              "567",
+							Database:        "someDB",
+							BucketID:        "456",
+							RetentionPolicy: "someRP",
+							Default:         true,
+							Virtual:         api.PtrBool(true),
 							OrgID:           "1234123412341234",
 						},
 					},
@@ -83,6 +94,9 @@ func TestClient_List(t *testing.T) {
 				`123\s+someDB\s+456\s+someRP\s+false\s+1234123412341234`,
 				`234\s+someDB\s+456\s+someRP\s+true\s+1234123412341234`,
 			},
+			virtLines: []string{
+				`567\s+someDB\s+456\s+someRP\s+true\s+1234123412341234`,
+			},
 		},
 		{
 			name: "api error",
@@ -120,7 +134,15 @@ func TestClient_List(t *testing.T) {
 			require.Equal(t, tc.expectedError, err)
 
 			if tc.expectedError == nil {
-				testutils.MatchLines(t, append([]string{`ID\s+Database\s+Bucket\s+ID\s+Retention Policy\s+Default\s+Organization ID`}, tc.outLines...), strings.Split(stdout.String(), "\n"))
+				header := `ID\s+Database\s+Bucket\s+ID\s+Retention Policy\s+Default\s+Organization ID`
+				testutils.MatchLines(t,
+					append([]string{header},
+						append(tc.outLines,
+							append([]string{
+								`VIRTUAL DBRP MAPPINGS \(READ-ONLY\)`,
+								"----------------------------------",
+								header}, tc.virtLines...)...)...),
+					strings.Split(stdout.String(), "\n"))
 			}
 		})
 	}
